==> core-2.0.0-sources.jar: ru/tinkoff/acquiring/sdk/utils/TestPaymentData.kt <==
/*
 * Copyright © 2020 Tinkoff Bank
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package ru.tinkoff.acquiring.sdk.utils

/**
 * @author Mariya Chernyadieva
 */
object TestPaymentData {

    const val TEST_PASS = "5l9v23g7hlhqchyb"
    const val TEST_TERMINAL_KEY = "TestSDK"
    const val TEST_CUSTOMER_KEY = "user-key"
    const val TEST_PAY_FORM = "Checkout"
    const val TEST_CUSTOMER_EMAIL = "testCustomerKey1@gmail.com"
    const val TEST_PUBLIC_KEY = "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5Yg3RyEkszggDVMDHCAG\n" +
            "zJm0mYpYT53BpasrsKdby8iaWJVACj8ueR0Wj3Tu2BY64HdIoZFvG0v7UqSFztE/\n" +
            "zUvnznbXVYguaUcnRdwao9gLUQO2I/097SHF9r++BYI0t6EtbbcWbfi755A1EWfu\n" +
            "9tdZYXTrwkqgU9ok2UIZCPZ4evVDEzDCKH6ArphVc4+iKFrzdwbFBmPmwi5Xd6CB\n" +
            "9Na2kRoPYBHePGzGgYmtKgKMNs+6rdv5v9VB3k7CS/lSIH4p74/OPRjyryo6Q7Nb\n" +
            "L+evz0+s60Qz5gbBRGfqCA57lUiB3hfXQZq5/q1YkABOHf9cR6Ov5nTRSOnjORgP\n" +
            "jwIDAQAB"

    const val TEST_CARD_PAN = "4300000000000777"
    const val TEST_CARD_EXPIRY_DATE = "11/22"
    const val TEST_CARD_SECURITY_CODE = "111"
}

==> core-2.0.4-sources.jar: ru/tinkoff/acquiring/sdk/utils/TestPaymentData.kt <==
/*
 * Copyright © 2020 Tinkoff Bank
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package ru.tinkoff.acquiring.sdk.utils

/**
 * @author Mariya Chernyadieva
 */
object TestPaymentData {

    const val TEST_PASS = "12345678"
    const val TEST_TERMINAL_KEY = "TestSDK"
    const val TEST_CUSTOMER_KEY = "user-key-test"
    const val TEST_PAY_FORM = "Checkout"
    const val TEST_CUSTOMER_EMAIL = "testCustomerKey1@gmail.com"
    const val TEST_PUBLIC_KEY = "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5Yg3RyEkszggDVMDHCAG\n" +
            "zJm0mYpYT53BpasrsKdby8iaWJVACj8ueR0Wj3Tu2BY64HdIoZFvG0v7UqSFztE/\n" +
            "zUvnznbXVYguaUcnRdwao9gLUQO2I/097SHF9r++BYI0t6EtbbcWbfi755A1EWfu\n" +
            "9tdZYXTrwkqgU9ok2UIZCPZ4evVDEzDCKH6ArphVc4+iKFrzdwbFBmPmwi5Xd6CB\n" +
            "9Na2kRoPYBHePGzGgYmtKgKMNs+6rdv5v9VB3k7CS/lSIH4p74/OPRjyryo6Q7Nb\n" +
            "L+evz0+s60Qz5gbBRGfqCA57lUiB3hfXQZq5/q1YkABOHf9cR6Ov5nTRSOnjORgP\n" +
            "jwIDAQAB"

    const val TEST_CARD_PAN = "4300000000000777"
    const val TEST_CARD_EXPIRY_DATE = "11/22"
    const val TEST_CARD_SECURITY_CODE = "111"
}
